#### General

Name
  {$ ctrl.node.name | noValue $}
Maintenance
  {$ ctrl.node.maintenance | yesno $}
Maintenance Reason
  {$ ctrl.node.maintenance_reason | noValue $}
Inspection Started At
  {$ ctrl.node.inspection_started_at | date: 'medium' | noValue $}
Inspection Finished At
  {$ ctrl.node.inspection_finished_at | date: 'medium' | noValue $}
Reservation
  {$ ctrl.node.reservation | noValue $}
Console Enabled
  {$ ctrl.node.console_enabled | yesno $}

#### Provisioning Status

Instance ID
  {$ ctrl.node.instance_uuid | noValue $}
Power State
  {$ ctrl.node.power_state | noValue $}
Target Power State
  {$ ctrl.node.target_power_state | noValue $}
Provision State
  {$ ctrl.node.provision_state | noValue $}
Target Provision State
  {$ ctrl.node.target_provision_state | noValue $}
Clean Step
  {$ ctrl.node.clean_step $}
Last Error
  {$ ctrl.node.last_error | noValue $}
Updated At
  {$ ctrl.node.updated_at | date: 'medium' | noValue $}